==> pyrefly-0.10.1.tar.gz: pyrefly-0.10.1/pyrefly/lib/lib.rs <==
/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

#![warn(clippy::all)]
#![allow(clippy::enum_variant_names)]
#![allow(clippy::manual_flatten)]
#![allow(clippy::match_like_matches_macro)]
#![allow(clippy::module_inception)]
#![allow(clippy::needless_lifetimes)]
#![allow(clippy::new_without_default)]
#![allow(clippy::single_match)]
#![allow(clippy::too_many_arguments)]
#![allow(clippy::type_complexity)]
#![allow(clippy::wrong_self_convention)]
#![deny(clippy::cloned_instead_of_copied)]
#![deny(clippy::derive_partial_eq_without_eq)]
#![deny(clippy::inefficient_to_string)]
#![deny(clippy::str_to_string)]
#![deny(clippy::string_to_string)]
#![deny(clippy::trivially_copy_pass_by_ref)]
#![feature(associated_const_equality)]
#![feature(associated_type_defaults)]
#![feature(box_patterns)]
#![feature(const_type_name)]
#![feature(if_let_guard)]
#![feature(let_chains)]
#![feature(once_wait)]

mod alt;
mod binding;
#[cfg(not(target_arch = "wasm32"))]
mod commands;
mod config;
mod dunder;
mod error;
mod export;
mod graph;
mod metadata;
mod module;
pub mod playground;
mod report;
mod ruff;
mod solver;
mod state;
mod test;
mod types;
mod util;

#[cfg(not(target_arch = "wasm32"))]
pub use crate::commands::run;
pub use crate::config::ConfigFile;
pub use crate::config::PythonEnvironment;
pub use crate::metadata::PythonVersion;
pub use crate::util::args::clap_env;
pub use crate::util::args::get_args_expanded;
pub use crate::util::fs_upward_search;
pub use crate::util::globs;
pub use crate::util::listing::FileList;
pub use crate::util::notify_watcher::NotifyWatcher;
pub use crate::util::thread_pool::init_thread_pool;
pub use crate::util::trace::init_tracing;
pub use crate::util::watcher::Watcher;

==> pyrefly-0.10.2.tar.gz: pyrefly-0.10.2/pyrefly/lib/lib.rs <==
/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

#![warn(clippy::all)]
#![allow(clippy::enum_variant_names)]
#![allow(clippy::manual_flatten)]
#![allow(clippy::match_like_matches_macro)]
#![allow(clippy::module_inception)]
#![allow(clippy::needless_lifetimes)]
#![allow(clippy::new_without_default)]
#![allow(clippy::single_match)]
#![allow(clippy::too_many_arguments)]
#![allow(clippy::type_complexity)]
#![allow(clippy::wrong_self_convention)]
#![deny(clippy::cloned_instead_of_copied)]
#![deny(clippy::derive_partial_eq_without_eq)]
#![deny(clippy::inefficient_to_string)]
#![deny(clippy::str_to_string)]
#![deny(clippy::string_to_string)]
#![deny(clippy::trivially_copy_pass_by_ref)]
#![feature(associated_const_equality)]
#![feature(associated_type_defaults)]
#![feature(box_patterns)]
#![feature(const_type_name)]
#![feature(if_let_guard)]
#![feature(let_chains)]
#![feature(never_type)]

mod alt;
mod binding;
#[cfg(not(target_arch = "wasm32"))]
mod commands;
mod config;
mod dunder;
mod error;
mod export;
mod graph;
mod metadata;
mod module;
pub mod playground;
mod report;
mod ruff;
mod solver;
mod state;
mod test;
mod types;
mod util;

#[cfg(not(target_arch = "wasm32"))]
pub use crate::commands::run;
pub use crate::config::config::ConfigFile;
pub use crate::config::environment::PythonEnvironment;
pub use crate::config::finder;
pub use crate::metadata::PythonPlatform;
pub use crate::metadata::PythonVersion;
pub use crate::util::args::clap_env;
pub use crate::util::args::get_args_expanded;
pub use crate::util::globs;
pub use crate::util::listing::FileList;
pub use crate::util::notify_watcher::NotifyWatcher;
pub use crate::util::thread_pool::init_thread_pool;
pub use crate::util::trace::init_tracing;
pub use crate::util::watcher::Watcher;
